@@ -12,6 +12,7 @@ import websockets
 
 from skylark.utils.utils import get_websocket_auth_token, get_bytes_from_file
 from skylark.constants.constants import HOST
+from skylark.utils.utils import is_connected
 
 
 class Service(Enum):
@@ -90,10 +91,15 @@ class RealTimeClient:
 			time.sleep(1)
 			continue
 		try:
-			await self.websocket.send(json.dumps({
-				"action": 'set_batch_size',
-				"batchSize": batch_size
-			}))
+			if is_connected():
+				await self.websocket.send(json.dumps({
+					"action": 'set_batch_size',
+					"batchSize": batch_size
+				}))
+			else:
+				self.websocket = None
+				await self.on_network_status_change()
+
 		except websockets.exceptions.ConnectionClosed:
 			print("connection closed in setting batch size")
 			print("re-establishing connection...")
@@ -108,11 +114,17 @@ class RealTimeClient:
 			print("none found")
 			continue
 		try:
-			await self.websocket.send(json.dumps({
-				"fileSize": byte_length,
-				"syncId": syncid,
-				"action": "start_frame"
-			}))
+			if is_connected():
+				print("sending frames!!")
+				await self.websocket.send(json.dumps({
+					"fileSize": byte_length,
+					"syncId": syncid,
+					"action": "start_frame"
+				}))
+			else:
+				self.websocket = None
+				await self.on_network_status_change()
+
 		except websockets.exceptions.ConnectionClosed:
 			print("connection closed in starting frame")
 			print("re-establishing connection...")
@@ -125,8 +137,13 @@ class RealTimeClient:
 			time.sleep(1)
 			continue
 		try:
+			if is_connected():
 			# the converted bytearray is sent using websockets
-			await self.websocket.send(array)
+				await self.websocket.send(array)
+			else:
+				self.websocket = None
+				await self.on_network_status_change()
+
 		except websockets.exceptions.ConnectionClosed:
 			print("connection closed in sending frame")
 			print("re-establishing connection...")
@@ -165,8 +182,10 @@ class RealTimeClient:
 				self.websocket = await websockets.client.connect(self.url, ssl=True)
 				if self.websocket.open:
 					print("Connection established correctly. Client Connected!")
+						
 				await asyncio.sleep(1)
 			except socket.gaierror:
+				print("client.py socket error!!")
 				time.sleep(1)
 				await self.on_network_status_change()
 		else:
@@ -174,6 +193,6 @@ class RealTimeClient:
 
 	async def re_connect(self):
 		# if internet is down we try and reconnect
-		self.websocket = None
-		print("Internet not found while reconnecting..")
-		await self._connect()
+		if self.websocket is None:
+			print("Internet not found while reconnecting..")
+			await self._connect()
